Module types

Module types 

Structs

CallEdgeRef
CodebaseSummary
ConflictDetail
ConnectResult
Result of a successful CONNECT handshake.
ContextResult
Result of a CONTEXT query.
DependencyRef
MergeConflict
MergeSuccess
SubmitError
SubmitResult
Result of a SUBMIT operation.
SymbolRef
SymbolResult
VerifyStepResult
WatchEvent

Enums

Change
A high-level representation of a code change that the SDK translates into the proto Change message before sending to the server.
Depth
Depth of context retrieval.
Filter
Filter for watch events.
MergeResult
Result of a MERGE operation.